ModuleFlags

Struct ModuleFlags 

pub struct ModuleFlags(/* private fields */);
Module access flags used in Java class files.

The ModuleAccessFlags type represents the access flags in the Module attribute of a Java class file.

Examples

use ristretto_classfile::byte_reader::ByteReader;
use ristretto_classfile::attributes::ModuleAccessFlags;

// Create flags using individual constants
let flags = ModuleAccessFlags::OPEN | ModuleAccessFlags::SYNTHETIC;

// Test for specific flags
assert!(flags.contains(ModuleAccessFlags::OPEN));
assert!(flags.contains(ModuleAccessFlags::SYNTHETIC));
assert!(!flags.contains(ModuleAccessFlags::MANDATED));

// Convert to string representation
assert_eq!(flags.to_string(), "(0x1020) ACC_OPEN, ACC_SYNTHETIC");

// Serialize to bytes
let mut bytes = Vec::new();
flags.to_bytes(&mut bytes)?;
assert_eq!(bytes, vec![0x10, 0x20]);

// Deserialize from bytes
let mut reader = ByteReader::new(&bytes);
let deserialized = ModuleAccessFlags::from_bytes(&mut reader)?;
assert_eq!(deserialized, flags);

References

Implementations

Source

impl ModuleAccessFlags

pub const OPEN: ModuleAccessFlags

Indicates that this module is open.

pub const SYNTHETIC: ModuleAccessFlags

Indicates that this module was not explicitly or implicitly declared.

pub const MANDATED: ModuleAccessFlags

Indicates that this module was implicitly declared.

Source

impl ModuleAccessFlags

pub const fn empty() -> ModuleAccessFlags

Get a flags value with all bits unset.

pub const fn all() -> ModuleAccessFlags

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<ModuleAccessFlags>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> ModuleAccessFlags

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> ModuleAccessFlags

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<ModuleAccessFlags>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: ModuleAccessFlags) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: ModuleAccessFlags) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: ModuleAccessFlags)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: ModuleAccessFlags)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: ModuleAccessFlags)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: ModuleAccessFlags, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: ModuleAccessFlags) -> ModuleAccessFlags

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: ModuleAccessFlags) -> ModuleAccessFlags

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: ModuleAccessFlags) -> ModuleAccessFlags

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference( self, other: ModuleAccessFlags, ) -> ModuleAccessFlags

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> ModuleAccessFlags

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl ModuleAccessFlags

pub const fn iter(&self) -> Iter<ModuleAccessFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ModuleAccessFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl ModuleAccessFlags

pub fn from_bytes( bytes: &mut ByteReader<'_>, ) -> Result<ModuleAccessFlags, Error>

Deserialize the ModuleAccessFlags from bytes.

Errors

Should not occur; reserved for future use.

Examples
use ristretto_classfile::byte_reader::ByteReader;
use ristretto_classfile::attributes::ModuleAccessFlags;

let mut bytes = ByteReader::new(&[0x00, 0x20]); // ACC_OPEN
let flags = ModuleAccessFlags::from_bytes(&mut bytes)?;
assert_eq!(flags, ModuleAccessFlags::OPEN);
pub fn to_bytes(&self, bytes: &mut Vec<u8>) -> Result<(), Error>

Serialize the ModuleAccessFlags to bytes.

Errors

Should not occur; reserved for future use.

Examples
use ristretto_classfile::attributes::ModuleAccessFlags;

let flags = ModuleAccessFlags::OPEN | ModuleAccessFlags::SYNTHETIC;
let mut bytes = Vec::new();
flags.to_bytes(&mut bytes)?;
assert_eq!(bytes, vec![0x10, 0x20]); // 0x0020 | 0x1000