pub struct ModuleFlags(/* private fields */);Expand description
Module access flags used in Java class files.
The ModuleAccessFlags type represents the access flags in the Module attribute of a Java
class file.
Examples
use ristretto_classfile::byte_reader::ByteReader;
use ristretto_classfile::attributes::ModuleAccessFlags;
// Create flags using individual constants
let flags = ModuleAccessFlags::OPEN | ModuleAccessFlags::SYNTHETIC;
// Test for specific flags
assert!(flags.contains(ModuleAccessFlags::OPEN));
assert!(flags.contains(ModuleAccessFlags::SYNTHETIC));
assert!(!flags.contains(ModuleAccessFlags::MANDATED));
// Convert to string representation
assert_eq!(flags.to_string(), "(0x1020) ACC_OPEN, ACC_SYNTHETIC");
// Serialize to bytes
let mut bytes = Vec::new();
flags.to_bytes(&mut bytes)?;
assert_eq!(bytes, vec![0x10, 0x20]);
// Deserialize from bytes
let mut reader = ByteReader::new(&bytes);
let deserialized = ModuleAccessFlags::from_bytes(&mut reader)?;
assert_eq!(deserialized, flags);References
Implementations
Sourceimpl ModuleAccessFlags
impl ModuleAccessFlags
Sourcepub const OPEN: ModuleAccessFlags
pub const OPEN: ModuleAccessFlags
Indicates that this module is open.
Sourcepub const SYNTHETIC: ModuleAccessFlags
pub const SYNTHETIC: ModuleAccessFlags
Indicates that this module was not explicitly or implicitly declared.
Sourcepub const MANDATED: ModuleAccessFlags
pub const MANDATED: ModuleAccessFlags
Indicates that this module was implicitly declared.
Sourceimpl ModuleAccessFlags
impl ModuleAccessFlags
Sourcepub const fn empty() -> ModuleAccessFlags
pub const fn empty() -> ModuleAccessFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ModuleAccessFlags
pub const fn all() -> ModuleAccessFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<ModuleAccessFlags>
pub const fn from_bits(bits: u16) -> Option<ModuleAccessFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> ModuleAccessFlags
pub const fn from_bits_truncate(bits: u16) -> ModuleAccessFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> ModuleAccessFlags
pub const fn from_bits_retain(bits: u16) -> ModuleAccessFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ModuleAccessFlags>
pub fn from_name(name: &str) -> Option<ModuleAccessFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ModuleAccessFlags) -> bool
pub const fn intersects(&self, other: ModuleAccessFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ModuleAccessFlags) -> bool
pub const fn contains(&self, other: ModuleAccessFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ModuleAccessFlags)
pub fn insert(&mut self, other: ModuleAccessFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ModuleAccessFlags)
pub fn remove(&mut self, other: ModuleAccessFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ModuleAccessFlags)
pub fn toggle(&mut self, other: ModuleAccessFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ModuleAccessFlags, value: bool)
pub fn set(&mut self, other: ModuleAccessFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ModuleAccessFlags) -> ModuleAccessFlags
pub const fn intersection(self, other: ModuleAccessFlags) -> ModuleAccessFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ModuleAccessFlags) -> ModuleAccessFlags
pub const fn union(self, other: ModuleAccessFlags) -> ModuleAccessFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ModuleAccessFlags) -> ModuleAccessFlags
pub const fn difference(self, other: ModuleAccessFlags) -> ModuleAccessFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ModuleAccessFlags,
) -> ModuleAccessFlags
pub const fn symmetric_difference( self, other: ModuleAccessFlags, ) -> ModuleAccessFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ModuleAccessFlags
pub const fn complement(self) -> ModuleAccessFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ModuleAccessFlags
impl ModuleAccessFlags
Sourcepub const fn iter(&self) -> Iter<ModuleAccessFlags>
pub const fn iter(&self) -> Iter<ModuleAccessFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ModuleAccessFlags>
pub const fn iter_names(&self) -> IterNames<ModuleAccessFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ModuleAccessFlags
impl ModuleAccessFlags
Sourcepub fn from_bytes(
bytes: &mut ByteReader<'_>,
) -> Result<ModuleAccessFlags, Error>
pub fn from_bytes( bytes: &mut ByteReader<'_>, ) -> Result<ModuleAccessFlags, Error>
Deserialize the ModuleAccessFlags from bytes.
Errors
Should not occur; reserved for future use.
Examples
use ristretto_classfile::byte_reader::ByteReader;
use ristretto_classfile::attributes::ModuleAccessFlags;
let mut bytes = ByteReader::new(&[0x00, 0x20]); // ACC_OPEN
let flags = ModuleAccessFlags::from_bytes(&mut bytes)?;
assert_eq!(flags, ModuleAccessFlags::OPEN);Sourcepub fn to_bytes(&self, bytes: &mut Vec<u8>) -> Result<(), Error>
pub fn to_bytes(&self, bytes: &mut Vec<u8>) -> Result<(), Error>
Serialize the ModuleAccessFlags to bytes.
Errors
Should not occur; reserved for future use.
Examples
use ristretto_classfile::attributes::ModuleAccessFlags;
let flags = ModuleAccessFlags::OPEN | ModuleAccessFlags::SYNTHETIC;
let mut bytes = Vec::new();
flags.to_bytes(&mut bytes)?;
assert_eq!(bytes, vec![0x10, 0x20]); // 0x0020 | 0x1000Trait Implementations
Sourceimpl Binary for ModuleAccessFlags
impl Binary for ModuleAccessFlags
Sourceimpl BitAnd for ModuleAccessFlags
impl BitAnd for ModuleAccessFlags
Sourcefn bitand(self, other: ModuleAccessFlags) -> ModuleAccessFlags
fn bitand(self, other: ModuleAccessFlags) -> ModuleAccessFlags
The bitwise and (&) of the bits in two flags values.
Sourcetype Output = ModuleAccessFlags
type Output = ModuleAccessFlags
& operator.Sourceimpl BitAndAssign for ModuleAccessFlags
impl BitAndAssign for ModuleAccessFlags
Sourcefn bitand_assign(&mut self, other: ModuleAccessFlags)
fn bitand_assign(&mut self, other: ModuleAccessFlags)
The bitwise and (&) of the bits in two flags values.
Sourceimpl BitOr for ModuleAccessFlags
impl BitOr for ModuleAccessFlags
Sourcefn bitor(self, other: ModuleAccessFlags) -> ModuleAccessFlags
fn bitor(self, other: ModuleAccessFlags) -> ModuleAccessFlags
The bitwise or (|) of the bits in two flags values.
Sourcetype Output = ModuleAccessFlags
type Output = ModuleAccessFlags
| operator.Sourceimpl BitOrAssign for ModuleAccessFlags
impl BitOrAssign for ModuleAccessFlags
Sourcefn bitor_assign(&mut self, other: ModuleAccessFlags)
fn bitor_assign(&mut self, other: ModuleAccessFlags)
The bitwise or (|) of the bits in two flags values.
Sourceimpl BitXor for ModuleAccessFlags
impl BitXor for ModuleAccessFlags
Sourcefn bitxor(self, other: ModuleAccessFlags) -> ModuleAccessFlags
fn bitxor(self, other: ModuleAccessFlags) -> ModuleAccessFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcetype Output = ModuleAccessFlags
type Output = ModuleAccessFlags
^ operator.Sourceimpl BitXorAssign for ModuleAccessFlags
impl BitXorAssign for ModuleAccessFlags
Sourcefn bitxor_assign(&mut self, other: ModuleAccessFlags)
fn bitxor_assign(&mut self, other: ModuleAccessFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourceimpl Clone for ModuleAccessFlags
impl Clone for ModuleAccessFlags
Sourcefn clone(&self) -> ModuleAccessFlags
fn clone(&self) -> ModuleAccessFlags
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ModuleAccessFlags
impl Debug for ModuleAccessFlags
Sourceimpl Default for ModuleAccessFlags
impl Default for ModuleAccessFlags
Sourcefn default() -> ModuleAccessFlags
fn default() -> ModuleAccessFlags
Sourceimpl Display for ModuleAccessFlags
impl Display for ModuleAccessFlags
Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Implements the Display trait for ModuleAccessFlags, allowing flags to be printed in a human-readable format.
The output format consists of:
- The hexadecimal value of the flags in parentheses (e.g., “(0x0020)”)
- A list of named flags separated by commas (e.g., “
ACC_OPEN, ACC_SYNTHETIC”)
Examples
use ristretto_classfile::attributes::ModuleAccessFlags;
let flags = ModuleAccessFlags::OPEN | ModuleAccessFlags::SYNTHETIC;
let output = flags.to_string();
assert_eq!(output, "(0x1020) ACC_OPEN, ACC_SYNTHETIC");
let empty = ModuleAccessFlags::empty();
assert_eq!(empty.to_string(), "(0x0000) ");Sourceimpl Extend<ModuleAccessFlags> for ModuleAccessFlags
impl Extend<ModuleAccessFlags> for ModuleAccessFlags
Sourcefn extend<T>(&mut self, iterator: T)where
T: IntoIterator<Item = ModuleAccessFlags>,
fn extend<T>(&mut self, iterator: T)where
T: IntoIterator<Item = ModuleAccessFlags>,
The bitwise or (|) of the bits in each flags value.
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)Sourceimpl Flags for ModuleAccessFlags
impl Flags for ModuleAccessFlags
Sourceconst FLAGS: &'static [Flag<ModuleAccessFlags>]
const FLAGS: &'static [Flag<ModuleAccessFlags>]
Sourcefn from_bits_retain(bits: u16) -> ModuleAccessFlags
fn from_bits_retain(bits: u16) -> ModuleAccessFlags
Sourcefn known_bits(&self) -> Self::Bits
fn known_bits(&self) -> Self::Bits
Sourcefn unknown_bits(&self) -> Self::Bits
fn unknown_bits(&self) -> Self::Bits
Sourcefn contains_unknown_bits(&self) -> bool
fn contains_unknown_bits(&self) -> bool
true if any unknown bits are set.Sourcefn from_bits_truncate(bits: Self::Bits) -> Self
fn from_bits_truncate(bits: Self::Bits) -> Self
Sourcefn from_name(name: &str) -> Option<Self>
fn from_name(name: &str) -> Option<Self>
Sourcefn iter_names(&self) -> IterNames<Self>
fn iter_names(&self) -> IterNames<Self>
Sourcefn iter_defined_names() -> IterDefinedNames<Self>
fn iter_defined_names() -> IterDefinedNames<Self>
Self::FLAGS.Sourcefn intersects(&self, other: Self) -> boolwhere
Self: Sized,
fn intersects(&self, other: Self) -> boolwhere
Self: Sized,
Sourcefn contains(&self, other: Self) -> boolwhere
Self: Sized,
fn contains(&self, other: Self) -> boolwhere
Self: Sized,
Sourcefn insert(&mut self, other: Self)where
Self: Sized,
fn insert(&mut self, other: Self)where
Self: Sized,
|) of the bits in two flags values.Sourcefn remove(&mut self, other: Self)where
Self: Sized,
fn remove(&mut self, other: Self)where
Self: Sized,
&!). Read moreSourcefn toggle(&mut self, other: Self)where
Self: Sized,
fn toggle(&mut self, other: Self)where
Self: Sized,
^) of the bits in two flags values.Sourcefn intersection(self, other: Self) -> Self
fn intersection(self, other: Self) -> Self
&) of the bits in two flags values.Sourcefn difference(self, other: Self) -> Self
fn difference(self, other: Self) -> Self
&!). Read moreSourcefn symmetric_difference(self, other: Self) -> Self
fn symmetric_difference(self, other: Self) -> Self
^) of the bits in two flags values.Sourcefn complement(self) -> Self
fn complement(self) -> Self
!) of the bits in a flags value, truncating the result.Sourceimpl FromIterator<ModuleAccessFlags> for ModuleAccessFlags
impl FromIterator<ModuleAccessFlags> for ModuleAccessFlags
Sourcefn from_iter<T>(iterator: T) -> ModuleAccessFlagswhere
T: IntoIterator<Item = ModuleAccessFlags>,
fn from_iter<T>(iterator: T) -> ModuleAccessFlagswhere
T: IntoIterator<Item = ModuleAccessFlags>,
The bitwise or (|) of the bits in each flags value.
Sourceimpl IntoIterator for ModuleAccessFlags
impl IntoIterator for ModuleAccessFlags
Sourcetype Item = ModuleAccessFlags
type Item = ModuleAccessFlags
Sourcetype IntoIter = Iter<ModuleAccessFlags>
type IntoIter = Iter<ModuleAccessFlags>
Sourcefn into_iter(self) -> <ModuleAccessFlags as IntoIterator>::IntoIter
fn into_iter(self) -> <ModuleAccessFlags as IntoIterator>::IntoIter
Sourceimpl LowerHex for ModuleAccessFlags
impl LowerHex for ModuleAccessFlags
Sourceimpl Not for ModuleAccessFlags
impl Not for ModuleAccessFlags
Sourcefn not(self) -> ModuleAccessFlags
fn not(self) -> ModuleAccessFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourcetype Output = ModuleAccessFlags
type Output = ModuleAccessFlags
! operator.Sourceimpl Octal for ModuleAccessFlags
impl Octal for ModuleAccessFlags
Sourceimpl PartialEq for ModuleAccessFlags
impl PartialEq for ModuleAccessFlags
Sourceimpl Sub for ModuleAccessFlags
impl Sub for ModuleAccessFlags
Sourcefn sub(self, other: ModuleAccessFlags) -> ModuleAccessFlags
fn sub(self, other: ModuleAccessFlags) -> ModuleAccessFlags
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcetype Output = ModuleAccessFlags
type Output = ModuleAccessFlags
- operator.Sourceimpl SubAssign for ModuleAccessFlags
impl SubAssign for ModuleAccessFlags
Sourcefn sub_assign(&mut self, other: ModuleAccessFlags)
fn sub_assign(&mut self, other: ModuleAccessFlags)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourceimpl UpperHex for ModuleAccessFlags
impl UpperHex for ModuleAccessFlags
impl Copy for ModuleAccessFlags
impl Eq for ModuleAccessFlags
impl StructuralPartialEq for ModuleAccessFlags